/*===========================================================================
algdef.h

algorithm result define
algorithm parameter define
===========================================================================*/
#ifndef __ALG_DEF_H__
#define __ALG_DEF_H__
#include "TypeDef.h"

//*************************************************************************
//
//                         algorithm parameter Enumerations
//
//*************************************************************************

#define COMMON8BIT_MAX_NUM 66
#define MAX_USER_NUM 74
#define MAX_DF_NUM 8

enum PSDU_FORMAT
{
    HE_SU = 1,          //HE-SU
    HE_MU = 2,          //HE-MU
    HE_ERSU = 3,        //HE-ERSU
    HE_TriggerBase = 4, //HE-TriggerBase
};

//enum for trigger base
enum GILTF_SIZE
{
    GILTFSize0,
    GILTFSize1,
    GILTFSize2,
};
//end enum for trigger base

enum HELTF_TYPE
{
    LTFSize_1x = 1, //1x LTFSize
    LTFSize_2x = 2, //2x LTFSize
    LTFSize_4x = 4, //4x LTFSize
};

enum MONDULATION_TYPE
{
    BPSK = 2,
    QPSK = 4,
    QAM16 = 16,
    QAM64 = 64,
    QAM256 = 256,
    QAM1024 = 1024
};

enum CODE_RATE
{
    Rate_1_2 = 12,  //1/2
    Rate_2_3 = 23,  //2/3
    Rate_3_4 = 34,  //3/4
    Rate_5_6 = 56,  //5/6
};

// Enumeration for PASS/FAIL values.
enum WT_PF_ENUM
{
    // Measurement passed.
    WT_PF_PASS,
    // Measurement failed.
    WT_PF_FAIL,
    // Pass/fail status is undefined.
    WT_PF_UNDEFINED
};

// Enumeration for phase correction mode - 802.11 a/g setting.
enum WT_PH_CORR_ENUM
{
    // Phase correction off.
    WT_PH_CORR_OFF = 1,
    // Symbol-by-symbol correction.  - Default value.
    WT_PH_CORR_SYM_BY_SYM = 2,
    // Moving avg. correction  - 10 symbols
    WT_PH_CORR_MOVING_AVG = 3
};

// Enumeration for phase correction mode - 802.11 b setting.
enum WT_PH_CORR_11b_ENUM
{
    // Phase correction off.
    WT_PH_CORR_11b_OFF = 1,
    // Symbol-by-symbol correction. - Default value.
    WT_PH_CORR_11b_ON = 2,
};

// Enumeration for channel estimate - 802.11 a/g setting.
enum WT_CH_EST_ENUM
{
    // Raw Channel Estimate - long train. - Default value.
    WT_CH_EST_RAW = 1,
    // Same as WT_CH_EST_RAW.
    WT_CH_EST_RAW_LONG = WT_CH_EST_RAW,
    // 2nd Order Polyfit.
    WT_CH_EST_2ND_ORDER = 2,
    // Raw Channel Estimate - full packet
    WT_CH_EST_RAW_FULL = 3
};

// Enumeration for Symbol Timing Correction - 802.11 a/g setting.
enum WT_SYM_TIM_ENUM
{
    // Symbol Timing Correction Off.
    WT_SYM_TIM_OFF = 1,
    // Symbol Timing Correction On - Default value.
    WT_SYM_TIM_ON = 2
};

// Enumeration for Frequency Sync. Mode - 802.11 a/g setting.
enum WT_FREQ_SYNC_ENUM
{
    // Short Training Symbol.  - Default value.
    WT_FREQ_SYNC_SHORT_TRAIN = 1,
    // Long Training Symbol
    WT_FREQ_SYNC_LONG_TRAIN = 2,
    // Full Data Packet.
    WT_FREQ_SYNC_FULL_PACKET = 3
};

// Enumeration for Amplitude Tracking - 802.11 a/g setting.
enum WT_AMPL_TRACK_ENUM
{
    // Amplitude tracking off.  - Default value.
    WT_AMPL_TRACK_OFF = 1,
    // Amplitude tracking on
    WT_AMPL_TRACK_ON = 2
};

// Enumeration for 802.11 b method - 802.11 b setting.
enum WT_11B_METHOD_ENUM
{
    // Use 11b standard TX accuracy - Default value.
    WT_11B_STANDARD_TX_ACC = 1,
    // Use 11b RMS error vector.
    WT_11B_RMS_ERROR_VECTOR = 2,
    //Use 11b Std 2007 TX accuracy
    WT_11B_STANDARD_2007_TX_ACC = 3
};

// Enumeration for Number of equalizer taps - 802.11 b setting.
enum WT_EQ_ENUM
{
    // Equalizer Off. - Default value.
    WT_EQ_OFF = 1,
    // 5 taps equalizer
    WT_EQ_5_TAPS = 5,
    // 7 taps equalizer.
    WT_EQ_7_TAPS = 7,
    // 9 taps equalizer.
    WT_EQ_9_TAPS = 9
};

// Enumeration for DC removal - 802.11 b setting.
enum WT_DC_REMOVAL_ENUM
{
    // DC removal Off  - Default value.
    WT_DC_REMOVAL_OFF = 0,
    // DC removal On.
    WT_DC_REMOVAL_ON = 1
};

// Enumeration for data capture handling.
enum WT_DC_ENUM
{
    // Arm the WT160 tester for new data capture.
    WT_DC_ARM_NEW,
    // Auto Range Process.
    IQV_DC_ARM_AUTORANGE,
    // Undefined default value.
    WT_DC_UNDEFINED
};

// Enumeration for enabling and disabling swapping of I and Q signals.
enum WT_IQ_SWAP_ENUM
{
    // IQ swap has been disabled.  -default
    WT_IQ_SWAP_DISABLED,
    // IQ swap has been enabled.
    WT_IQ_SWAP_ENABLED
};

//Enumeration for enabling and disabling reversion of I and Q signals.
enum WT_IQ_Reversion_ENUM
{
    // - Default value.
    WT_IQ_IQReversion_DISABLED,
    WT_IQ_IReversion_ENABLED,
    WT_IQ_QReversion_ENABLED,
    WT_IQ_IQReversion_ENABLED
};

enum WT_ZB_ANALYSIS_OPTIMISE_ENUM
{
    WT_ZB_ANALYSIS_OPTIMISE_DISABLED,
    WT_ZB_ANALYSIS_OPTIMISE_ENABLED,
};

//Enumeration for frame bandwidth dectecting.
enum WT_BANDWIDTH_DETECT_ENUM
{
    // - Default value.
    WT_USER_DEFINED,
    WT_BW_AUTO_DETECT,
    WT_AUTO_DETECT
};

enum WT_DEMOD_ENUM
{
    // 11a/g
    WT_DEMOD_11AG,
    // 11b
    WT_DEMOD_11B,
    // 11n 20M
    WT_DEMOD_11N_20M,
    // 11n 40M
    WT_DEMOD_11N_40M,
    // 11ac 20M
    WT_DEMOD_11AC_20M,
    // 11ac 40M
    WT_DEMOD_11AC_40M,
    // 11ac 80M
    WT_DEMOD_11AC_80M,
    // 11ac 160M
    WT_DEMOD_11AC_160M,
    // 11ac 80+80M
    WT_DEMOD_11AC_80_80M,
    // Bluetooth
    WT_DEMOD_BT,
    // Zigbee
    WT_DEMOD_ZIGBEE,
    // 11ah 1M
    WT_DEMOD_11AH_1M,
    // 11ah 2M
    WT_DEMOD_11AH_2M,
    // 11ah 4M
    WT_DEMOD_11AH_4M,
    // 11ah 8M
    WT_DEMOD_11AH_8M,
    // 11ah 16M
    WT_DEMOD_11AH_16M,

    //ContinuesWave
    WT_DEMOD_CW,

    //11p
    WT_DEMOD_11P_5M,
    WT_DEMOD_11P_10M,

    //lora
    WT_DEMOD_LORA_125K,
    WT_DEMOD_LORA_250K,
    WT_DEMOD_LORA_500K,

    // 11ax 20M
    WT_DEMOD_11AX_20M,
    // 11ax 40M
    WT_DEMOD_11AX_40M,
    // 11ax 80M
    WT_DEMOD_11AX_80M,
    // 11ax 160M
    WT_DEMOD_11AX_160M,
    // 11ax 80+80M
    WT_DEMOD_11AX_80_80M,
    // 11ax 160+160M
    WT_DEMOD_11AX_160_160M,

    //802.15.4g
    WT_DEMOD_LRWPAN_FSK,
    WT_DEMOD_LRWPAN_OQPSK,
    WT_DEMOD_LRWPAN_OFDM,

    //ZWave
    WT_DEMOD_ZWAVE,
    //NB-IOT
    WT_DEMOD_NBIOT_NPUSCH,
    WT_DEMOD_NBIOT_NPRACH,
    // Unknow
    WT_DEMOD_UNKNOW = 0xFF
};

//Enumeration for BT DataRate.
enum WT_BT_DATARATE
{
    WT_BT_DATARATE_Auto = 0,
    WT_BT_DATARATE_1M = 1,  //1M
    WT_BT_DATARATE_2M = 2,  //2M
    WT_BT_DATARATE_3M = 3,  //3M
    WT_BT_DATARATE_BLE_1M = 4,  //BLE_1M
    WT_BT_DATARATE_BLE_2M = 5,  //BLE_2M
    WT_BT_DATARATE_BLE_125K = 6,   //BLE_125K
    WT_BT_DATARATE_BLE_500K = 7,   //BLE_500K
    //WT_BT_DATARATE_BLE_Coded = 6 //BLE_1M,帧格式不一样
};


//Enumeration for BT Packet type.
enum WT_BT_PACKETTYPE
{
    WT_BT_PACKETTYPE_NULL = 0,
    WT_BT_PACKETTYPE_POLL = 1,
    WT_BT_PACKETTYPE_FHS = 2,
    WT_BT_PACKETTYPE_DH1 = 3,
    WT_BT_PACKETTYPE_DH3 = 4,
    WT_BT_PACKETTYPE_DH5 = 5,
    WT_BT_PACKETTYPE_DM1 = 6,
    WT_BT_PACKETTYPE_DM3 = 7,
    WT_BT_PACKETTYPE_DM5 = 8,
    WT_BT_PACKETTYPE_HV1 = 9,
    WT_BT_PACKETTYPE_HV2 = 10,
    WT_BT_PACKETTYPE_HV3 = 11,
    WT_BT_PACKETTYPE_DV = 12,
    WT_BT_PACKETTYPE_AUX1 = 13,
    WT_BT_PACKETTYPE_EV3 = 14,
    WT_BT_PACKETTYPE_EV4 = 15,
    WT_BT_PACKETTYPE_EV5 = 16,
    WT_BT_PACKETTYPE_2_DH1 = 17,
    WT_BT_PACKETTYPE_2_DH3 = 18,
    WT_BT_PACKETTYPE_2_DH5 = 19,
    WT_BT_PACKETTYPE_3_DH1 = 20,
    WT_BT_PACKETTYPE_3_DH3 = 21,
    WT_BT_PACKETTYPE_3_DH5 = 22,
    WT_BT_PACKETTYPE_2_EV3 = 23,
    WT_BT_PACKETTYPE_2_EV5 = 24,
    WT_BT_PACKETTYPE_3_EV3 = 25,
    WT_BT_PACKETTYPE_3_EV5 = 26
};

//coding rate
enum WT_CODING_RATE
{
    WT_RATE_12,    // 1/2
    WT_RATE_23,    // 2/3
    WT_RATE_34,    // 3/4
    WT_RATE_56     // 5/6
};

enum WT_STANDARD_ENUM
{
    IEEE802_11_a_g_OFDM,
    IEEE802_11_b_g_DSSS,
    IEEE802_11_n,
    IEEE802_11_ac,
    Bluetooth,
    IEEE_Zigbee,
    ContinuousWaves,
    IEEE802_11_ax,
    StandardCount
};

enum DATARATE_11A_ENUM
{
    //OFDM
    Mbps54 = 0,
    Mbps48,
    Mbps36,
    Mbps24,
    Mbps18,
    Mbps12,
    Mbps9,
    Mbps6
};

enum DATARATE_11B_ENUM
{
    //DSSS
    Mbps11 = 100,
    Mbps5point5,
    Mbps2,
    Mbps1
};

enum DATARATE_MISC_ENUM
{
    //CW
    Sin1MHz = 800,
    Sin0Hz,
    Sin100KHz,
    SinNeg100KHz,

    //Buletooth
    Mbps3_prbs9 = 1000,
    Mbps3_11110000,
    Mbps3_1111,
    Mbps3_00001111,
    Mbps3_1010,
    Mbps3_0101,
    Mbps3_0000,

    Mbps2_prbs9,
    Mbps2_11110000,
    Mbps2_1111,
    Mbps2_00001111,
    Mbps2_1010,
    Mbps2_0101,
    Mbps2_0000,

    Mbps1_prbs9,
    Mbps1_11110000,
    Mbps1_1111,
    Mbps1_00001111,
    Mbps1_1010,
    Mbps1_0101,
    Mbps1_0000
};

enum DATARATE_11N_ENUM
{
    MCS31 = 300,
    MCS30,
    MCS29,
    MCS28,
    MCS27,
    MCS26,
    MCS25,
    MCS24,

    MCS23,
    MCS22,
    MCS21,
    MCS20,
    MCS19,
    MCS18,
    MCS17,
    MCS16,

    MCS15,
    MCS14,
    MCS13,
    MCS12,
    MCS11,
    MCS10,
    MCS9,
    MCS8,

    MCS7,
    MCS6,
    MCS5,
    MCS4,
    MCS3,
    MCS2,
    MCS1,
    MCS0,

    //40M
    MCS31_40 = 400,
    MCS30_40,
    MCS29_40,
    MCS28_40,
    MCS27_40,
    MCS26_40,
    MCS25_40,
    MCS24_40,

    MCS23_40,
    MCS22_40,
    MCS21_40,
    MCS20_40,
    MCS19_40,
    MCS18_40,
    MCS17_40,
    MCS16_40,

    MCS15_40,
    MCS14_40,
    MCS13_40,
    MCS12_40,
    MCS11_40,
    MCS10_40,
    MCS9_40,
    MCS8_40,

    MCS7_40,
    MCS6_40,
    MCS5_40,
    MCS4_40,
    MCS3_40,
    MCS2_40,
    MCS1_40,
    MCS0_40
};

enum DATARATE_11AC_ENUM
{
    NSS8_MCS11 = 450,
    NSS8_MCS10,
    NSS8_MCS9,
    NSS8_MCS8,
    NSS8_MCS7,
    NSS8_MCS6,
    NSS8_MCS5,
    NSS8_MCS4,
    NSS8_MCS3,
    NSS8_MCS2,
    NSS8_MCS1,
    NSS8_MCS0,

    NSS7_MCS11,
    NSS7_MCS10,
    NSS7_MCS9,
    NSS7_MCS8,
    NSS7_MCS7,
    NSS7_MCS6,
    NSS7_MCS5,
    NSS7_MCS4,
    NSS7_MCS3,
    NSS7_MCS2,
    NSS7_MCS1,
    NSS7_MCS0,

    NSS6_MCS11,
    NSS6_MCS10,
    NSS6_MCS9,
    NSS6_MCS8,
    NSS6_MCS7,
    NSS6_MCS6,
    NSS6_MCS5,
    NSS6_MCS4,
    NSS6_MCS3,
    NSS6_MCS2,
    NSS6_MCS1,
    NSS6_MCS0,

    NSS5_MCS11,
    NSS5_MCS10,
    NSS5_MCS9,
    NSS5_MCS8,
    NSS5_MCS7,
    NSS5_MCS6,
    NSS5_MCS5,
    NSS5_MCS4,
    NSS5_MCS3,
    NSS5_MCS2,
    NSS5_MCS1,
    NSS5_MCS0,



    NSS4_MCS11 = 500,
    NSS4_MCS10,
    NSS4_MCS9,
    NSS4_MCS8,
    NSS4_MCS7,
    NSS4_MCS6,
    NSS4_MCS5,
    NSS4_MCS4,
    NSS4_MCS3,
    NSS4_MCS2,
    NSS4_MCS1,
    NSS4_MCS0,

    NSS3_MCS11,
    NSS3_MCS10,
    NSS3_MCS9,
    NSS3_MCS8,
    NSS3_MCS7,
    NSS3_MCS6,
    NSS3_MCS5,
    NSS3_MCS4,
    NSS3_MCS3,
    NSS3_MCS2,
    NSS3_MCS1,
    NSS3_MCS0,

    NSS2_MCS11,
    NSS2_MCS10,
    NSS2_MCS9,
    NSS2_MCS8,
    NSS2_MCS7,
    NSS2_MCS6,
    NSS2_MCS5,
    NSS2_MCS4,
    NSS2_MCS3,
    NSS2_MCS2,
    NSS2_MCS1,
    NSS2_MCS0,

    NSS1_MCS11,
    NSS1_MCS10,
    NSS1_MCS9,
    NSS1_MCS8,
    NSS1_MCS7,
    NSS1_MCS6,
    NSS1_MCS5,
    NSS1_MCS4,
    NSS1_MCS3,
    NSS1_MCS2,
    NSS1_MCS1,
    NSS1_MCS0,

    //40M
    NSS8_MCS11_40 = 550,
    NSS8_MCS10_40,
    NSS8_MCS9_40,
    NSS8_MCS8_40,
    NSS8_MCS7_40,
    NSS8_MCS6_40,
    NSS8_MCS5_40,
    NSS8_MCS4_40,
    NSS8_MCS3_40,
    NSS8_MCS2_40,
    NSS8_MCS1_40,
    NSS8_MCS0_40,

    NSS7_MCS11_40,
    NSS7_MCS10_40,
    NSS7_MCS9_40,
    NSS7_MCS8_40,
    NSS7_MCS7_40,
    NSS7_MCS6_40,
    NSS7_MCS5_40,
    NSS7_MCS4_40,
    NSS7_MCS3_40,
    NSS7_MCS2_40,
    NSS7_MCS1_40,
    NSS7_MCS0_40,

    NSS6_MCS11_40,
    NSS6_MCS10_40,
    NSS6_MCS9_40,
    NSS6_MCS8_40,
    NSS6_MCS7_40,
    NSS6_MCS6_40,
    NSS6_MCS5_40,
    NSS6_MCS4_40,
    NSS6_MCS3_40,
    NSS6_MCS2_40,
    NSS6_MCS1_40,
    NSS6_MCS0_40,

    NSS5_MCS11_40,
    NSS5_MCS10_40,
    NSS5_MCS9_40,
    NSS5_MCS8_40,
    NSS5_MCS7_40,
    NSS5_MCS6_40,
    NSS5_MCS5_40,
    NSS5_MCS4_40,
    NSS5_MCS3_40,
    NSS5_MCS2_40,
    NSS5_MCS1_40,
    NSS5_MCS0_40,


    NSS4_MCS11_40 = 600,
    NSS4_MCS10_40,
    NSS4_MCS9_40,
    NSS4_MCS8_40,
    NSS4_MCS7_40,
    NSS4_MCS6_40,
    NSS4_MCS5_40,
    NSS4_MCS4_40,
    NSS4_MCS3_40,
    NSS4_MCS2_40,
    NSS4_MCS1_40,
    NSS4_MCS0_40,

    NSS3_MCS11_40,
    NSS3_MCS10_40,
    NSS3_MCS9_40,
    NSS3_MCS8_40,
    NSS3_MCS7_40,
    NSS3_MCS6_40,
    NSS3_MCS5_40,
    NSS3_MCS4_40,
    NSS3_MCS3_40,
    NSS3_MCS2_40,
    NSS3_MCS1_40,
    NSS3_MCS0_40,

    NSS2_MCS11_40,
    NSS2_MCS10_40,
    NSS2_MCS9_40,
    NSS2_MCS8_40,
    NSS2_MCS7_40,
    NSS2_MCS6_40,
    NSS2_MCS5_40,
    NSS2_MCS4_40,
    NSS2_MCS3_40,
    NSS2_MCS2_40,
    NSS2_MCS1_40,
    NSS2_MCS0_40,

    NSS1_MCS11_40,
    NSS1_MCS10_40,
    NSS1_MCS9_40,
    NSS1_MCS8_40,
    NSS1_MCS7_40,
    NSS1_MCS6_40,
    NSS1_MCS5_40,
    NSS1_MCS4_40,
    NSS1_MCS3_40,
    NSS1_MCS2_40,
    NSS1_MCS1_40,
    NSS1_MCS0_40,

    //80M
    NSS8_MCS11_80 = 650,
    NSS8_MCS10_80,
    NSS8_MCS9_80,
    NSS8_MCS8_80,
    NSS8_MCS7_80,
    NSS8_MCS6_80,
    NSS8_MCS5_80,
    NSS8_MCS4_80,
    NSS8_MCS3_80,
    NSS8_MCS2_80,
    NSS8_MCS1_80,
    NSS8_MCS0_80,

    NSS7_MCS11_80,
    NSS7_MCS10_80,
    NSS7_MCS9_80,
    NSS7_MCS8_80,
    NSS7_MCS7_80,
    NSS7_MCS6_80,
    NSS7_MCS5_80,
    NSS7_MCS4_80,
    NSS7_MCS3_80,
    NSS7_MCS2_80,
    NSS7_MCS1_80,
    NSS7_MCS0_80,

    NSS6_MCS11_80,
    NSS6_MCS10_80,
    NSS6_MCS9_80,
    NSS6_MCS8_80,
    NSS6_MCS7_80,
    NSS6_MCS6_80,
    NSS6_MCS5_80,
    NSS6_MCS4_80,
    NSS6_MCS3_80,
    NSS6_MCS2_80,
    NSS6_MCS1_80,
    NSS6_MCS0_80,

    NSS5_MCS11_80,
    NSS5_MCS10_80,
    NSS5_MCS9_80,
    NSS5_MCS8_80,
    NSS5_MCS7_80,
    NSS5_MCS6_80,
    NSS5_MCS5_80,
    NSS5_MCS4_80,
    NSS5_MCS3_80,
    NSS5_MCS2_80,
    NSS5_MCS1_80,
    NSS5_MCS0_80,

    NSS4_MCS11_80 = 700,
    NSS4_MCS10_80,
    NSS4_MCS9_80,
    NSS4_MCS8_80,
    NSS4_MCS7_80,
    NSS4_MCS6_80,
    NSS4_MCS5_80,
    NSS4_MCS4_80,
    NSS4_MCS3_80,
    NSS4_MCS2_80,
    NSS4_MCS1_80,
    NSS4_MCS0_80,

    NSS3_MCS11_80,
    NSS3_MCS10_80,
    NSS3_MCS9_80,
    NSS3_MCS8_80,
    NSS3_MCS7_80,
    NSS3_MCS6_80,
    NSS3_MCS5_80,
    NSS3_MCS4_80,
    NSS3_MCS3_80,
    NSS3_MCS2_80,
    NSS3_MCS1_80,
    NSS3_MCS0_80,

    NSS2_MCS11_80,
    NSS2_MCS10_80,
    NSS2_MCS9_80,
    NSS2_MCS8_80,
    NSS2_MCS7_80,
    NSS2_MCS6_80,
    NSS2_MCS5_80,
    NSS2_MCS4_80,
    NSS2_MCS3_80,
    NSS2_MCS2_80,
    NSS2_MCS1_80,
    NSS2_MCS0_80,

    NSS1_MCS11_80,
    NSS1_MCS10_80,
    NSS1_MCS9_80,
    NSS1_MCS8_80,
    NSS1_MCS7_80,
    NSS1_MCS6_80,
    NSS1_MCS5_80,
    NSS1_MCS4_80,
    NSS1_MCS3_80,
    NSS1_MCS2_80,
    NSS1_MCS1_80,
    NSS1_MCS0_80,

    //160M
    NSS8_MCS11_160 = 850,
    NSS8_MCS10_160,
    NSS8_MCS9_160,
    NSS8_MCS8_160,
    NSS8_MCS7_160,
    NSS8_MCS6_160,
    NSS8_MCS5_160,
    NSS8_MCS4_160,
    NSS8_MCS3_160,
    NSS8_MCS2_160,
    NSS8_MCS1_160,
    NSS8_MCS0_160,

    NSS7_MCS11_160,
    NSS7_MCS10_160,
    NSS7_MCS9_160,
    NSS7_MCS8_160,
    NSS7_MCS7_160,
    NSS7_MCS6_160,
    NSS7_MCS5_160,
    NSS7_MCS4_160,
    NSS7_MCS3_160,
    NSS7_MCS2_160,
    NSS7_MCS1_160,
    NSS7_MCS0_160,

    NSS6_MCS11_160,
    NSS6_MCS10_160,
    NSS6_MCS9_160,
    NSS6_MCS8_160,
    NSS6_MCS7_160,
    NSS6_MCS6_160,
    NSS6_MCS5_160,
    NSS6_MCS4_160,
    NSS6_MCS3_160,
    NSS6_MCS2_160,
    NSS6_MCS1_160,
    NSS6_MCS0_160,

    NSS5_MCS11_160,
    NSS5_MCS10_160,
    NSS5_MCS9_160,
    NSS5_MCS8_160,
    NSS5_MCS7_160,
    NSS5_MCS6_160,
    NSS5_MCS5_160,
    NSS5_MCS4_160,
    NSS5_MCS3_160,
    NSS5_MCS2_160,
    NSS5_MCS1_160,
    NSS5_MCS0_160,

    NSS4_MCS11_160 = 900,
    NSS4_MCS10_160,
    NSS4_MCS9_160,
    NSS4_MCS8_160,
    NSS4_MCS7_160,
    NSS4_MCS6_160,
    NSS4_MCS5_160,
    NSS4_MCS4_160,
    NSS4_MCS3_160,
    NSS4_MCS2_160,
    NSS4_MCS1_160,
    NSS4_MCS0_160,

    NSS3_MCS11_160,
    NSS3_MCS10_160,
    NSS3_MCS9_160,
    NSS3_MCS8_160,
    NSS3_MCS7_160,
    NSS3_MCS6_160,
    NSS3_MCS5_160,
    NSS3_MCS4_160,
    NSS3_MCS3_160,
    NSS3_MCS2_160,
    NSS3_MCS1_160,
    NSS3_MCS0_160,

    NSS2_MCS11_160,
    NSS2_MCS10_160,
    NSS2_MCS9_160,
    NSS2_MCS8_160,
    NSS2_MCS7_160,
    NSS2_MCS6_160,
    NSS2_MCS5_160,
    NSS2_MCS4_160,
    NSS2_MCS3_160,
    NSS2_MCS2_160,
    NSS2_MCS1_160,
    NSS2_MCS0_160,

    NSS1_MCS11_160,
    NSS1_MCS10_160,
    NSS1_MCS9_160,
    NSS1_MCS8_160,
    NSS1_MCS7_160,
    NSS1_MCS6_160,
    NSS1_MCS5_160,
    NSS1_MCS4_160,
    NSS1_MCS3_160,
    NSS1_MCS2_160,
    NSS1_MCS1_160,
    NSS1_MCS0_160
};

enum PREAMBLE_TYPE
{
    PRE_LONG_11B,
    PRE_SHORT_11B
};

enum HT_FRAME_TYPE_ENUM
{
    FRM_HT_MF = 1,
    FRM_HT_GF
};

enum PSDU_TYPE_ENUM
{
    enPSDUType_USER,
    PSDUType_ALL0 = 1,
    PSDUType_ALL1,
    PSDUType_ALT01,
    PSDUType_RANDOM,
    PSDUType_PRBS9,
    PSDUType_PRBS15,
    PSDUType_TriggerFrame = 100,
};

enum iBEAFORMING_CHIP_ENUM
{
    iBEAFORMING_INIT_ENUM = 0,
    //For BCM Implicit Beamforming
    iBEAFORMING_BCM_STATE_1 = 1,
    iBEAFORMING_BCM_STATE_2,
    //For MTK Implicit Beamforming
    iBEAFORMING_MTK_STATE_1 = 10,
    iBEAFORMING_MTK_STATE_2
};

enum SPECTRUM_MASK_VERSION
{
    Ieee2009,
    Ieee2012
};

//纠错码
enum WT_ERROR_CORRECTING_CODE
{
    WT_BCC,     //BCC
    WT_LDPC,    //LDPC
};

enum WT_ULDL
{
    WT_DL,
    WT_UL
};

enum WT_PREAMBLE_TYPE
{
    WT_PREAMBLE_LONG,
    WT_PREAMBLE_SHORT,
};

//clockrate enum
enum WT_CLOCK_RATE
{
    WT_CLOCK_RATE_1 = 1,
    WT_CLOCK_RATE_1_2 = 2,
    WT_CLOCK_RATE_1_4 = 4,
    WT_CLOCK_RATE_1_5 = 5,
    WT_CLOCK_RATE_1_8 = 8,
    WT_CLOCK_RATE_1_10 = 10,
    WT_CLOCK_RATE_1_20 = 20,
};

/*================ 结果结构体定义 ========================================*/
#define UNVALID_VAL -999.99
#define MAX_SPECT_POINT_NUM  2400  //频谱图的最多点数，240M/100k
#define DF_Max_ChannalNum_11ax       2048

//算法基本结果
struct VsaBaseResult
{
    double PowerFrame;
    double PowerAll;
    double PowerPeak;

    double EvmAll;
    double EvmPeak;
    double EvmData;
    double EvmPilot;
    double EvmPsdu;
    double EvmShrPhr;

    double FreqOffset;
    double CarrierLeakage;
    double SymClkErr;
    double PhaseErr;
    double IQImbAmp;
    double IQImbPhase;
};

//11ag 11n 11ac 11ax mac 信息结构
typedef struct
{
    s32 validflag;                          //有效性
    char FrameCtrl_User[4];
    char FrameCtrl_Duration[4];
    char FrameCtrl_Sequence[4];
    char MAC_Address1[12];
    char MAC_Address2[12];
    char MAC_Address3[12];
    char MAC_Address4[12];
    s8 Type;
    s8 SubType;
}stMacInfo;

//11ax triggerbase unused tone error
struct TbUnusedToneError
{
    int valid_flag;             //界面画图有效性，0不生效，1生效
    int total_ru26_num;         //RU26个数，横坐标长度
    int mask_valid_flag[MAX_USER_NUM];    //模板有效性，在1时候才画模板值
    int mask_value[MAX_USER_NUM];         //模板值，当有效性为1时才显示
    double unused_tone_error[MAX_USER_NUM];//Tone Error值，整体是连续的
    double Reserved[128];       //保留位
};

//WIFI平均结果结构体，存放所有需要平均
typedef struct
{
    struct VsaBaseResult BaseResult;                                                            //基本结果
    int SpectNum;                                                                           //频谱点数
    int ChannelNum;                                                                     //子通道数
    double Spectrum[MAX_SPECT_POINT_NUM];                           //频谱图数据点值
    Complex SpectFlatnessData[DF_Max_ChannalNum_11ax];      //频谱平坦度数据值
} VsaAverageResult;

struct DataInfo11ag
{
    double DataRate;
    int SymbolCnt;
    int PsduLen;
    int CodeingRate;
    int Modulation;
};

struct DataInfo11b
{
    double DataRate;
    int Length;
    int PsduLen;
    int PreambleType;
    int SfdPass;
    int HeaderPass;
    int pad;
};

struct DataInfo11n
{
    double DataRate;
    int SymbolCnt;
    int CodeingRate;
    int PsduLen;
    int Modulation;

    int HTSigValid;
    int Mcs;
    int Cbw;
    int HTLen;
    int Smooth;
    int NotSnd;
    int Aggreg;
    int STBC;
    int FecCode;
    int ShortGi;
    int ExtSStrms;
    int Crc;
    int Tail;

    int LsigValid;
    int Rate;
    int Len;
    int Parity;
    int LsigTail;
};

struct DataInfo11ac
{
    double DataRate;
    int SymbolCnt;
    int CodeingRate;
    int PsduLen;
    int Modulation;

    int VHTSigAValid;
    int Mcs;
    int Bw;
    int STBC;
    int FecCode;
    int Crc;
    int ShortGi;
    int Nvhtltf;
    int Nsts;
    int Nss;
    int GroupId;

    int VHTSigBValid;
    int McsB;
    int Len;

    int LsigValid;
    int Rate;
    int LsigLen;
    int pad;
};

//ac mu mimo information
#define MAX_AC_USER_NUM 4
struct DataInfoAcMuMimo
{
    int MuMimoFlag;
    int MuMimoUserNum;
    int BW;
    int SymbolCnt;
    int STBC;
    int Nvhtltf;
    int ShortGi;
    int GroupId;
    int Reserved[66];

    struct {
        double DataRate;
        int PsduLen;
        int Crc;
        int Mcs;
        int Modulation;
        int FecCode;
        int CodingRate;
        int Nsts;
        int Nss;
        double AllEvm;
        double DataEvm;
        double PilotEvm;
        double UserPower;
        int UserNstsFlag[MAX_DF_NUM];
        double UserPowerNsts[MAX_DF_NUM];
        double PilotEvmNsts[MAX_DF_NUM];
        double DateEvmNsts[MAX_DF_NUM];
        double AllEvmNsts[MAX_DF_NUM];
        int vthbLength;
        int Reserved1;
        double Reserved[63];
    }UserInfo[MAX_AC_USER_NUM];
};

struct DataInfo11ax
{
    int HeSigAValid;
    int Bw;
    int PsduFormat;
    int UserNum;
    int SymbolCnt;
    int HeltfNum;
    int HeltType;
    int Reserved;       //预留字段，主要为了字节对齐
    double DataRate;
    double HeltfLen;
    double GILen;
    double HeDataSymLen;
    double FrameLen;

    int HeSigBValid;
    int SigBDcm;
    int SigBMcs;
    int SigBSymbol;
    int Common8BitLen;
    int Common8Bit[COMMON8BIT_MAX_NUM];

    int PreTxBF;
    int LDPCExtra;
    int PE;
    int PeLen;
    int PreFEC;
    int Doppler;
    int Midamble_Periodicity;
    int MuMimoFlag;            //1采用mu-mimo新结构读取，0保持原来模式不变，按原方式读取
    int SIGBCompression;       //mu-mimo下是表示1为全带宽，0为部分带宽
    int RealUserNum;           //有效的用户数
    int Reserved1[125];       // 预留字段，主要为了字节对齐


    struct
    {
        int Valid;
        int ULDL;
        int UserId;
        int ToneWide;
        int ToneIdx;
        int Isegment;
        int Mcs;
        int Modulation;
        int LDPC;
        int CodingRate;
        int STBC;
        int DCM;
        int Nsts;
        int PsduCrc;
        int PsduLen;
        int UserAID;
        double PowerFactor;
        double UserPower;
        double UserRate;
        double PilotEvm;
        double DataEvm;
        double AllEvm;
        int UserNstsFlag[MAX_DF_NUM];
        double UserPowerNsts[MAX_DF_NUM];
        double PilotEvmNsts[MAX_DF_NUM];
        double DateEvmNsts[MAX_DF_NUM];
        double AllEvmNsts[MAX_DF_NUM];
        double Reserved[28];       // 预留字段
    } UserInfo[MAX_USER_NUM];
};

struct UserInfo11ax
{
    int ULDL;
    int UserId;
    int ToneWide;
    int ToneIdx;
    int Isegment;
    int Mcs;
    int Modulation;
    int LDPC;
    int CodingRate;
    int STBC;
    int DCM;
    int Nsts;
    int PsduCrc;
    int PsduLen;
    int UserAID;
    int Reserved1; //对齐，预留字段
    double PowerFactor;
    double UserPower;
    double UserRate;
    double PilotEvm;
    double DataEvm;
    double AllEvm;
    int UserNstsFlag[MAX_DF_NUM];
    double UserPowerNsts[MAX_DF_NUM];
    double PilotEvmNsts[MAX_DF_NUM];
    double DateEvmNsts[MAX_DF_NUM];
    double AllEvmNsts[MAX_DF_NUM];
    double Reserved[32];       // 预留字段
};

//mu-mimo 单个ru的结构体
struct RuOfdmaInfo11ax
{
    int ValidFlag;  //Ru有效性，0为无效，0时其他内容都显示--
    int Ue_Num;     //Ru内的用户数
    int RuNsts;     //Ru的总流数
    int Reserved1;  //对齐，预留字段
    double q_matrix_r[8][8];
    double q_matrix_i[8][8];
    UserInfo11ax User[8];
    double Reserved[64];       // 预留字段
};

struct DataInfoBT
{
    double InitFreqErr;
    double OmegaI;
    double OmegaIO;
    double OmegaO;
    double DevmAvg;
    double DevmPeak;
    double DiffPower;
    double MaxFreqVar;
    double Devm;
    double FreqDrift;
    double FreqDriftRate;
    double F1Max;
    double F1Avg;
    double F2Max;
    double F2Avg;
    double FnMax;
    double F0FnMax;
    double F1F0;
    double FnFn5Max;
    double F0F3;
    double FnFn3;
    int DataRate;
    int PktType;
    int PktLen;
    int PayloadHeader;
    int CrcStatus;
};

struct DataInfoZwave    //zwave info
{
    double InitFreqErr;
    double FreqDeviRMS;
    double FreqDeviMAX;
    double FreqDeviMIN;
    double ZeroErrRMS;
    double ZeroErrPeak;
    double SymbolClockErr;
    double SymbolClockJitter;
    double DataRate;
    int PsduLen;
    int PsdeCrcPass;
    int SymbolCount;
    int Reserved[63];
};

//ZWave 眼图数据
typedef struct
{
    s32 chip;                            //每两个符号周期成一个chip号;每个chip的图都有自己的颜色
    double Ix;                              //I时间
    double Iy;                              //I幅度
    double Qx;                              //Q时间
    double Qy;                              //Q幅度
} stZWave_eye;

//ZigBee eye
typedef struct
{
    s32 chip;                               //所在chip号;每个chip的都有自己的颜色
    double Ix;                              //I时间
    double Iy;                              //I幅度
} st11Zigbee_eye;

typedef struct
{
    int chip;                //所在chip号;每个chip的都有自己的颜色
    double Ix;               //I时间
    double Iy;               //I幅度
    double Qx;               //Q时间
    double Qy;               //Q幅度
} st11B_eye;

typedef struct
{
    int evm_chip_start;     //EVM计算开始chip号
    int evm_chip_count;     //EVM计算的chip个数
} st11BChip;

typedef struct
{
    double time;
    double freq_Hz;
} stBT_FreqErr;

typedef struct
{
    double freq_Hz;
    double pwr_dBm;
    double pwr_mask_dBm;
} stBT_BW20dB;

typedef struct
{
    double time;
    double devm_percent;
} stBT_DEVM;

enum WT_ALZ_PARAM_TYPE
{
    WT_ALZ_PARAM_COMMON,
    WT_ALZ_PARAM_FFT,
    WT_ALZ_PARAM_WIFI,
    WT_ALZ_PARAM_BT,
    WT_ALZ_PARAM_ZIGBEE,
    WT_ALZ_PARAM_ZWAVE,
};

//WIFI分析参数
typedef struct
{
    int Demode;                                                     //分析模式,WT_DEMOD_ENUM,默认值WT_DEMOD_UNKNOW
    int AutoDetect;                                                 //信号带宽自动检测，详见WT_BANDWIDTH_DETECT_ENUM,默认值WT_BW_AUTO_DETECT

    int Method11b;                                              //802.11 b EVM方式.  WT_11B_METHOD_ENUM,默认值WT_11B_STANDARD_TX_ACC
    int DCRemoval;                                                  //802.11 b 直流去除. WT_DC_REMOVAL_ENUM,默认值WT_DC_REMOVAL_OFF
    int EqTaps;                                                     //802.11 b 均衡类型. WT_EQ_ENUM,默认值WT_EQ_OFF
    int PhsCorrMode11B;                                     //802.11 b 相位跟踪. WT_PH_CORR_11b_ENUM,默认值WT_PH_CORR_11b_ON

    int PhsCorrMode;                                                //802.11 a/b/g/n/ac 相位跟踪. WT_PH_CORR_ENUM,默认值WT_PH_CORR_SYM_BY_SYM
    int ChEstimate;                                                 //802.11 a/g/n/ac 通道估计. WT_CH_EST_ENUM,默认值WT_CH_EST_RAW
    int SynTimeCorr;                                                //802.11 a/g/n/ac 时序跟踪. WT_SYM_TIM_ENUM,默认值WT_SYM_TIM_ENUM
    int FreqSyncMode;                                           //802.11 a/g/n/ac 频率同步. WT_FREQ_SYNC_ENUM,默认值WT_FREQ_SYNC_ENUM
    int AmplTrack;                                                  //802.11 a/g/n/ac 幅度跟踪. WT_AMPL_TRACK_ENUM,默认值WT_AMPL_TRACK_ENUM
    int OfdmDemodOn;                                            //OFDM Demodulation, 1:on, 0:off,默认值1

    int MIMOAnalysisMode;                                   //MIMO分析模式,默认值0
    int MimoMaxPowerDiff;                                   //MIMO不同signal之间的最大功率差异，差异大于该值较低功率的会被当成干扰信号,默认值30
    int SpectrumMaskVersion;                            //SpecturmMask Version ，0：Ieee2009；1：Ieee2012,只在11n选择两种不同模板时使用~
    int ClockRate;                                      //压缩子载波间隔,赋值详见枚举
    char FullCRCFlag;                                   //全译码开关，0：FCS CRC； 1：FEC CRC
    char Reseverdchar[3];                               //字节对齐保留位
    int Reserved[1];                                    //保 留
} AlzParamWifi;

//BT分析参数
typedef struct
{
    int BTDataRate;                                                 //Bluetooth速率, WT_BT_DATARATE,默认值WT_BT_DATARATE_Auto
    int BTPktType;                                                  //Bluetooth包类型, WT_BT_PACKETTYPE(默认设置为WT_BT_PACKETTYPE_NULL即可)
    int Reserved[4];                                                    //保留
} AlzParamBT;

//ZigBee分析参数
typedef struct
{
    int Optimize;                                                       //是否开启优化，0 关闭， 1 开启，默认值0
} AlzParamZigBee;

//通用分析参数
typedef struct
{
    int IQSwap;                                                     //IQ交换(频谱反转). WT_IQ_SWAP_ENUM,默认值WT_IQSWAP_DISABLED
    int IQReversion;                                                //IQ极性反转.WT_IQ_Reversion_ENUM,默认值WT_IQ_IQReversion_DISABLED
    int ManualPktStart;                                         //指定数据包在多少个采样点后为起始,默认值0
    int FilterPktByTime;                                            //短包过滤，低于此时间长度的包会被过滤,默认值0
    int FilterPktByType;                                            //包类型过滤,默认值0
    double FreqOffset;                                          //输入信号频率偏移,默认值0
    int SpectrumFlag;
    int CcdfFlag;
    int Reserved[6];                                                    //保留
} AlzParamComm;

typedef struct
{
    //FFT分析参数
    int WindowType;                                             //WT_WINDOW_TYPE_ENUM,默认值WT_WINDOW_TYPE_Hann
    double Rbw;                                                     //resolution bandwidth, 默认值100000
    double Reserved[10];                                        //保留
} AlzParamFFT;

enum WT_ZWAVE_DATARATE
{
    WT_ZWAVE_DATARATE_R1 = 1,
    WT_ZWAVE_DATARATE_R2 = 2,
    WT_ZWAVE_DATARATE_R3 = 3,
};

//Zwave的分析参数
struct AlzParamZwave
{
    int ZwaveRate;              //速率设置，见枚举WT_ZWAVE_DATARATE，取值1=R1，2=R2，3=R3
    int Reserved[32];
};

typedef union
{
    AlzParamWifi analyzeParamWifi;
    AlzParamBT analyzeParamBt;
    AlzParamZigBee analyzeParamZigBee;
    AlzParamFFT   analyzeParamFft;
} AnalyzeParam;

//11ax Trigger Base分析参数
struct AlzParamAxTriggerBase
{
    int TBFlag;                        //是否必须按TriggerBase模式来解
    int UserNum;                       //总User数
    int UserID;                        //当前分析User
    int GILTFSize;                     //帧的GILTF:GILTFSize0, 1:GILTFSize1, 2:GILTFSize2
    int NumLTF;                        //帧的取值1,2,4,6,8
    int LDPCSym;                       //取值0,1
    int PEDisamb;                      //取值0,1
    int AFactor;                       //取值1,2,3,4
    int STBC;                          //STBC值
    int Doppler;
    int Midamble_Periodicity;

    int Stream[MAX_USER_NUM];     //取值1~8
    int MCS[MAX_USER_NUM];        //取值0~11
    int Segment[MAX_USER_NUM];    //取值0,1
    int RUIndex[MAX_USER_NUM];    //
    int Conding[MAX_USER_NUM];    //取值0:BCC、1:LDPC
    int DCM[MAX_USER_NUM];        //取值
    int AID[MAX_USER_NUM];
    int TBMUMIMOFlag;                   //TB MU-MIMO时为1，否则为0
    int NSSStart[MAX_USER_NUM];         //取值1-7，常规TB都为1
    int Reserved[107];
};

//wave生成文件后，才确定的参数变量值获取返回，目前主要是tb相关的内容
typedef struct
{
    int LDPCSym;
    int PEDisamb;
    int AFactor;
    int Doppler;
    int Midamble_Periodicity;
    int Reserved[256];
}AxTbVariableParameter;

//A-MPDU information
struct AmpduInfo
{
    int ampdu_ind;    //ampdu子帧序号
    int ampdu_length; //mpdu长度
    int crc;          //crc
    int Reserved[32];
};

/*=========================================================================
                                result define
==========================================================================*/

/* IQ data. Complex vector is returned. */
#define WT_RES_IQ                 "IQ.data"

/* IQ data mv. Complex vector is returned. */
#define WT_RES_IQ_MV               "IQ.data.mv"

/* sampling frequency. Int Value */
#define WT_RES_SMP_FREQ           "sampling.freq"

/* frame data info. for meter */
#define WT_RES_DATA_INFO           "data.info"

/* base result */
#define WT_RES_BASE_RESULT         "result.base"

/*mimo base result*/
#define WT_RES_BASE_RESULT_COMPOSITE "result.base.composite"

/* demode. Int Value */
#define WT_RES_DEMODE              "demode"

/* signal segment number. Int Value  */
#define WT_RES_SEGMENT_NUM         "segment.num"

/* rf gain. double Value  */
#define WT_RES_RF_GAIN             "gain"

/* external gain. double Value  */
#define WT_RES_EXT_GAIN            "ext_gain"

/* reference power level. double Value  */
#define WT_RES_REF_LEVEL           "ref.level"

/* trigger power level. double Value  */
#define WT_RES_TRIG_LEVEL          "trig.level"

/*===========================================================================
  CCDF Result
  ===========================================================================*/

/* Real vector containing CCDF probability values (Y-axis of CCDF plot) */
#define WT_RES_CCDF_PROB           "CCDF.prob"

/* Real vector containing CCDF power relative to average power in dB values
(X-axis of CCDF plot) */
#define WT_RES_CCDF_POWER_REL_DB   "CCDF.power_rel_dB"

/* ccdf start relative power. double Value dBm */
#define WT_RES_CCDF_START          "CCDF.start"

/* ccdf scale value dBm. double value */
#define WT_RES_CCDF_SCALE          "CCDF.scale"

/* Result for CCDF %10 %1 %0.1 %0.01 percentage‘s power. double vector Value is returned. */
#define WT_RES_CCDF_PERCENT_POWER    "CCDF.percent.power"
/*===========================================================================
  spectrum result
  ===========================================================================*/

/*Carrier leakage in dB.Value is returned*/
#define WT_RES_SPECTRUM_CARRIER_LEAKAGE  "Carrier_leakage"

/*OBW in Hz.Value is returned*/
#define WT_RES_SPECTRUM_OBW       "Obw"

/*OBW start Freq,int value*/
#define WT_RES_SPECTRUM_OBW_START_FREQ       "Obw_start_freq"

/*OBW end Freq,int value*/
#define WT_RES_SPECTRUM_OBW_END_FREQ       "Obw_end_freq"

//8080 第二段的obw，8080专用
/*OBW in Hz.Value is returned*/
#define WT_RES_SPECTRUM_OBW1       "Obw1"

/*OBW start Freq in Hz,int value*/
#define WT_RES_SPECTRUM_OBW_START_FREQ1       "Obw_start_freq1"

/*OBW end Freq in Hz,int value*/
#define WT_RES_SPECTRUM_OBW_END_FREQ1       "Obw_end_freq1"
//end 8080 obw

/*Spectrum mask error point in %.Value is returned*/
#define WT_RES_SPECTRUM_MASK_ERR  "Spec_mask_err"

/*Frequency of the max power in Hz.Value is returned*/
#define WT_RES_SPECTRUM_PEAK_FREQ  "Spec_peak_freq"

/*power of the max power in dBm.Value is returned*/
#define WT_RES_SPECTRUM_PEAK_POWER  "Spec_peak_power"

/* Y-axis values, power in dBm. Vector is returned. */
#define WT_RES_SPECTRUM_Y           "y"

/* spectrum maskm, power in dBm. Vector is returned */
#define WT_RES_SPECTRUM_MASK        "spectrum.mask"

/* spectrum rbw, value in HZ. Int Value */
#define WT_RES_SPECTRUM_RBW         "spectrum.rbw"

/* Resolution bandwidth used in calculations. Int Value is returned. */
#define WT_RES_SPECTRUM_RES_BW      "res_bw"

/*Center Frequency in Hz.Value is returned*/
#define WT_RES_SPECTRUM_FREQ_CENTER "Freq_center"

/*Frequency span in Hz. Int Value is returned*/
#define WT_RES_SPECTRUM_FREQ_SPAN   "Freq_span"

/*Spectrum margin data. Complex Vector is returned*/
#define  WT_RES_SPECTRUM_MARGIN_DATA  "Spec_margin_data"

/* 500M spectrum Y-axis values, power in dBm. Vector is returned. */
#define WT_RES_SPECTRUM_Y_500M           "y_500M"

/* 500M spectrum maskm, power in dBm. Vector is returned */
#define WT_RES_SPECTRUM_MASK_500M        "spectrum.mask_500M"
/*===========================================================================
  power result
  ===========================================================================*/

/* RMS Power in dB, no gap. */
#define WT_RES_RMS_DB_NO_GAP       "rms_db_nogap"

/* RMS Power in dB. */
#define WT_RES_RMS_DB              "rms_db"

/* Frame Count by Power Detectoring. Int Value is returned. */
#define WT_RES_POWER_FRAME_COUNT   "pow.frame.count"

/* Power Peak. Vector is returned. */
#define WT_RES_POWER_PEAK          "pow.peak"

/* points power. Vector is returned */
#define WT_RES_POINTS_POWER        "points.power"

/* window avg power. Vector is returned */
#define WT_RES_WIN_AVG_POWER       "avg.power"

/*===========================================================================
  OFDM & 11B result
  ===========================================================================*/

/* EVM for entire frame. Value is returned. */
#define WT_RES_EVM_ALL             "evm.all"

/* EVM for entire frame(%). Value is returned. */
#define WT_RES_EVM_ALL_PERCENT     "evm.all(%)"

/* EVM peak value. Value is returned. */
#define WT_RES_EVM_PEAK            "evm.pk"

/* EVM peak value(%). Value is returned. */
#define WT_RES_EVM_PEAK_PERCENT    "evm.pk(%)"

/* Frequency Error in Hz. Value is returned. */
#define WT_RES_FREQ_ERR_HZ         "signal.freqerr_hz"

/* Symbol Clock Error in ppm. Value is returned. */
#define WT_RES_SYMBOL_CLOCK_ERR    "signal.symclockerr"

/* IQ Match Amplitude Error in dB. Value is returned. */
#define WT_RES_IQ_MATCH_AMP_DB      "iqmatch.amp_dB"

/* IQ Match Phase Error in deg. Value is returned. */
#define WT_RES_IQ_MATCH_PHASE      "iqmatch.phase"

/* IQ Chanel DC Offset in dB. Value is returned. */
#define WT_RES_IQ_DC_OFFSET         "iq.offset"

/* const data in dB. Complex Vector is returned */
#define WT_RES_CONST_DATA          "const.data"

/* pilot const data in dB. Complex Vector is returned */
#define WT_RES_CONST_PILOT         "const.pilot"

/* reference const data in dB. Complex Vector is returned */
#define WT_RES_CONST_REF           "const.ref"

/* symbol evm avg. Vector is returned */
#define WT_RES_EVM_SYM_AVG         "evm.symbol.avg"

/* symbol evm. Vector is returned */
#define WT_RES_EVM_SYM             "evm.symbol"

/* symbol evm pilot. Complex Vector is returned */
#define WT_RES_EVM_SYM_PILOT       "evm.symbol.pilot"

/* carrier evm avg. Vector is returned */
#define WT_RES_EVM_CARRIER_AVG     "evm.carrier.avg"

/* pilot carrier evm avg. Vector is returned */
#define WT_RES_EVM_CARRIER_PILOT_AVG     "evm.carrier.pilot.avg"

/* carrier evm. Vector is returned */
#define WT_RES_EVM_CARRIER         "evm.carrier"

/* pilot carrier evm. Vector is returned */
#define WT_RES_EVM_CARRIER_PILOT   "evm.carrier.pilot"


/* symbol evm avg db. Vector is returned */
#define WT_RES_EVM_SYM_AVG_DB         "evm.symbol.avg.db"

/* symbol evm db. Vector is returned */
#define WT_RES_EVM_SYM_DB             "evm.symbol.db"

/* symbol evm pilot db. Vector is returned */
#define WT_RES_EVM_SYM_PILOT_DB       "evm.symbol.pilot.db"

/* carrier evm avg db. Vector is returned */
#define WT_RES_EVM_CARRIER_AVG_DB     "evm.carrier.avg.db"

/* pilot carrier evm avg db. Vector is returned */
#define WT_RES_EVM_CARRIER_PILOT_AVG_DB "evm.carrier.pilot.avg.db"

/* carrier evm db. Vector is returned */
#define WT_RES_EVM_CARRIER_DB         "evm.carrier.db"

/* pilot carrier evm db. Vector is returned */
#define WT_RES_EVM_CARRIER_PILOT_DB   "evm.carrier.pilot.db"

/* 11ax ltf type, int value is returned */
#define WT_RES_LTF_SIZE              "LTF.size"
/*========================================================================
 * 11ax SigB result
 * =======================================================================*/
/* symbol const data in dB. Complex Vector is returned */
#define WT_RES_SIGB_CONST_DATA      "sigb.const.data"

/* symbol const pilot in dB. Complex Vector is returned */
#define WT_RES_SIGB_CONST_PILOT     "sigb.const.pilot"

/* symbol reference const data in dB. Complex Vector is returned */
#define WT_RES_SIGB_CONST_REF       "sigb.const.ref"

/*sigb symbol evm . Vector is returned */
#define WT_RES_SIGB_EVM_SYM         "sigb.evm.symbol"

/*sigb carrier evm. Vector is returned */
#define WT_RES_SIGB_EVM_CARRIER     "sigb.evm.carrier"

/* Single element double Value */
/*sigb all evm*/
#define WT_RES_SIGB_EVM_ALL         "sigb.evm.all"

/* Single element double Value */
/*sigb pilot evm*/
#define WT_RES_SIGB_EVM_PILOT_DB    "sigb.evm.pilot"

/* Single element double Value */
/*sigb data evm*/
#define WT_RES_SIGB_EVM_DATA_DB     "sigb.evm.data"

/* double Value */
#define WT_RES_SIGB_EVM_ALL_COMPOSITE         "sigb.evm.all.composite"

/* double Value */
#define WT_RES_SIGB_EVM_PILOT_DB_COMPOSITE    "sigb.evm.pilot.composite"

/* double Value */
#define WT_RES_SIGB_EVM_DATA_DB_COMPOSITE     "sigb.evm.data.composite"

/*===========================================================================
  11ax user result
  ===========================================================================*/
/*all user's const data*/
#define WT_RES_ALL_USER_CONST_DATA  "all.user.const.data"

/*all user's const ref*/
#define WT_RES_ALL_USER_CONST_REF   "all.user.const.ref"

/*all user's const pilot*/
#define WT_RES_ALL_USER_CONST_PILOT "all.user.const.pilot"

/*specific user's const. data*/
#define WT_RES_11AX_USER_CONST_DATA     "user.const.data"

/*specific user's const ref*/
#define WT_RES_11AX_USER_CONST_REF      "user.const.ref"

/*specific user's const.pilot*/
#define WT_RES_11AX_USER_CONST_PILOT    "user.const.pilot"

/*11ax psdu format*/
#define WT_RES_11AX_PSDU_FORMAT         "ax.psdu.format"

/*========================================================================
 * 11ax SigA result
 * =======================================================================*/
/*siga color bit,int Value*/
#define WT_RES_11AX_SIGA_BSS_COLOR     "siga.bss.color"

/*========================================================================
 * 11ax TB result
 * =======================================================================*/
/*trigger base unused tone error,struct stTbUnusedToneError result is return*/
#define WT_RES_11AX_TB_UNUSED_TONE_ERROR    "tb.unused_tone_error"

/*trigger frame info, struct TF11ax is return*/
#define WT_RES_TRIGGER_FRAME_INFO           "trigger_frame.info"
/*===========================================================================
  11a 11ac 11n preamble freqErr
  ===========================================================================*/
/* 160 points data, vector is returned, double value*/
#define WT_RES_PREAMBLE_FREQ_ERR_HZ "preamble.freqErr_hz"

/* 160 points data, vector is returned, int value*/
#define WT_RES_PREAMBLE_FREQ_ERR_FLAG "preamble.freqErr.validFlag"

/*===========================================================================
  11B result
  ===========================================================================*/
/* 11b LO(DC) Leakage rbw. Int Value is returned. */
#define WT_RES_LO_LEAKAGE_RBW      "spectrum.lo.leakage.rbw"

/* 11b LO(DC) Leakage span. Int Value is returned. */
#define WT_RES_LO_LEAKAGE_SPAN      "spectrum.lo.leakage.span"

/* 11b LO(DC) Leakage .Vector is returned*/
#define WT_RES_LO_LEAKAGE          "spectrum.lo.leakage"

/* Real vector is returned */
/* Time vector for the data points in WT_RES_11B_FREQ_ERR */
#define WT_RES_11B_FREQ_ERR_TIME    "b11.freqErrTimeVect"

/* Real vector is returned */
/* 11b Preamble Frequency Error in Hz,Vector is returned. */
#define WT_RES_11B_FREQ_ERR     "b11.freqErr_hz"

/* Ramp on time. Value is returned. */
#define WT_RES_RAMP_ON_TIME        "ramp.on_time"

/* Ramp off time. Value is returned. */
#define WT_RES_RAMP_OFF_TIME       "ramp.off_time"

/* Single element double Value */
/* Phase Error */
#define WT_RES_11B_PHASE_ERR        "b11.phase_err"

/* Single element double Value */
/* Bit Rate, see 802.11b standard */
#define WT_RES_11B_BIT_RATE        "b11.PLCP_info.bit_rate"

/* Single element double Value */
/* Carrier Suppression */
#define WT_RES_11B_CARR_SUPPRESSION       "b11.carrier_suppression"

/* 11b eye data. st11B_eye Vector */
#define WT_RES_11B_EYE             "b11.eye"

/* power on ramp data. Complex Vector */
#define WT_RES_RAMP_ON_POWER_INST  "ramp.on_power_inst"

/* power on ramp peak data. Complex Vector */
#define WT_RES_RAMP_ON_POWER_PEAK  "ramp.on_power_peak"

/* power on ramp mask1 data. Complex Vector */
#define WT_RES_RAMP_ON_POWER_MARK1 "ramp.on_power_mask1"

/* power on ramp mask2 data. Complex Vector */
#define WT_RES_RAMP_ON_POWER_MARK2 "ramp.on_power_mask2"

/* power down ramp data. Complex Vector */
#define WT_RES_RAMP_OFF_POWER_INST "ramp.off_power_inst"

/* power down ramp peak data. Complex Vector */
#define WT_RES_RAMP_OFF_POWER_PEAK "ramp.off_power_peak"

/* power down ramp mask1 data. Complex Vector */
#define WT_RES_RAMP_OFF_POWER_MARK1 "ramp.off_power_mask1"

/* power down ramp mask2 data. Complex Vector */
#define WT_RES_RAMP_OFF_POWER_MARK2 "ramp.off_power_mask2"

/* evm vs time data. double vector */
#define WT_RES_EVM_TIME            "evm.time"

/* evm vs time avg data. double vector */
#define WT_RES_EVM_TIME_AVG        "evm.time.avg"

/* evm vs time chip info. st11BChip data */
#define WT_RES_EVM_TIME_CHIP       "evm.chip"

/*===========================================================================
  OFDM result
  ===========================================================================*/

/* Single element double Value */
/* Phase Error */
#define WT_RES_OFDM_PHASE_ERR        "ofdm.phase_err"

/* Number of Bytes in PSDU. Int Value */
#define WT_RES_PSDU_LENGTH          "psdu_length"

/* Single element double Value */
/* Data rate in Mbps */
#define WT_RES_OFDM_DATA_RATE_MBPS "ofdm.PLCP.Data_rate_Mbps"

/* Number of symbols. Int Value */
#define WT_RES_OFDM_NUMBER_SYMBOLS "ofdm.PLCP.Nspp"

/* EVM for data part of frame.dB. Value is returned. */
#define WT_RES_EVM_DATA_DB            "evm.data"

/* EVM for pilot part of frame.dB. Value is returned. */
#define WT_RES_EVM_PILOT_DB           "evm.pilot"

/*Spectrum Flatness Passed Or Failed. Int Value is returned*/
#define WT_RES_OFDM_SPECTRUM_FLATNESS_PASSED    "Spec_flatness_passed"

/*Spectrum Flatness Data. Vector is returned*/
#define  WT_RES_OFDM_SPECTRUM_FLATNESS_DATA     "Spec_flatness_data"

/*Spectrum Flatness Data. Vector is returned*/
#define  WT_RES_OFDM_SPECTRUM_FLATNESS_MASKUP_DATA      "Spec_flatness_maskup_data"

/*Spectrum Flatness Data. Vector is returned*/
#define  WT_RES_OFDM_SPECTRUM_FLATNESS_MASKDOWN_DATA    "Spec_flatness_maskdown_data"

/*Spectrum Flatness Section Value. Complex Vector is returned*/
#define WT_RES_OFDM_SPECTRUM_FLATNESS_SECTION_VALUE    "Spec_flatness_section_value"

/*Spectrum Flatness Section Margin. Complex Vector is returned*/
#define WT_RES_OFDM_SPECTRUM_FLATNESS_SECTION_MARGIN    "Spec_flatness_section_margin"

/*===========================================================================
  ZigBee result
  ===========================================================================*/

/* Single element double vector */
/* Phase Error */
#define WT_RES_ZIGBEE_PHASE_ERR                "zigbee.phase_err"
#define WT_RES_ZIGBEE_EVM_PSDU                 "zigbee.evm(psdu)"
#define WT_RES_ZIGBEE_EVM_PSDU_PERCENT         "zigbee.evm(psdu)"
#define WT_RES_ZIGBEE_EVM_SHRPHR               "zigbee.evm(shr+phr)"
#define WT_RES_ZIGBEE_EVM_SHRPHR_PERCENT       "zigbee.evm(shr+phr)"
#define WT_RES_ZIGBEE_EVM_OFFSET_DB            "zigbee.evm_offset"
#define WT_RES_ZIGBEE_EVM_OFFSET_PERCENT       "zigbee.evm_offset_percent"
/* st11Zigbee_eye vector is returned*/
#define WT_RES_ZIGBEE_EYE_REAL                 "zigbee.eye_real"
/* st11Zigbee_eye vector is returned*/
#define WT_RES_ZIGBEE_EYE_IMAG                 "zigbee.eye_imag"
/* double vector is returned, phase_err vs chip*/
#define WT_RES_ZIGBEE_PHASE_ERR_VS_CHIP        "zigbee.phase_err.chip"


/*===========================================================================
 Bluetooth result
 ===========================================================================*/

/* freq carrier offset of each burst detected, in Hz. */
/* stBT_FreqErr vector is returned. See BlueTooth Testing Documentation. */
#define WT_RES_BT_CARR_FREQ_BUF             "freq_est buffer"

/* Initial freq carrier drift of each burst detected, in Hz. */
/* Real vector is returned. See BlueTooth Testing Documentation. */
#define WT_RES_BT_CARR_FREQ_DRIFT          "freq_drift"

/* Initial freq carrier drift of each burst detected, in Hz. */
/* Real vector is returned. See BlueTooth Testing Documentation. */
#define WT_RES_BT_CARR_FREQ_DRIFT_RATE     "freq_drift_rate"

/* Initial freq offset of each burst detected, in Hz. */
/* Real vector is returned. See BlueTooth Testing Documentation. */
#define WT_RES_BT_CARR_FREQ_TOL            "freq_est"

/* The measurement result for deltaF1Avg as specified in
BLUETOOTH TEST SPECIFICATION Ver. 1.2/2.0/2.0 + EDR [vol 2] version 2.0.E.2
Requires 00001111 data pattern. Result in Hz */
#define WT_RES_BT_DELTA_F1_AVG             "deltaF1Average"

/* WT_RES_BT_DELTA_F1_AVG is valid or not. Int Value
1 - valid
0 - invalid */
#define WT_RES_BT_DELTA_F1_VALID             "deltaF1Valid"

/* The measurement result for deltaF2Max as specified in
BLUETOOTH TEST SPECIFICATION Ver. 1.2/2.0/2.0 + EDR [vol 2] version 2.0.E.2
Requires alternating data pattern. Result in Hz */
#define WT_RES_BT_DELTA_F2_MAX             "deltaF2Max"

/* The measurement result for deltaF2Avg as specified in
BLUETOOTH TEST SPECIFICATION Ver. 1.2/2.0/2.0 + EDR [vol 2] version 2.0.E.2
Requires alternating data pattern. Result in Hz */
#define WT_RES_BT_DELTA_F2_AVG             "deltaF2Average"

/* WT_RES_BT_DELTA_F2_MAX(WT_RES_BT_DELTA_F2_AVG) is valid or not. Int Value
1 - valid
0 - invalid */
#define WT_RES_BT_DELTA_F2_VALID             "deltaF2Valid"

/* Indicates validity of WT_RES_BT_RMS_DEVM. Int Value */
#define WT_RES_BT_RMS_DEVM_VALID            "EdrEVMvalid"

/* RMS Differential EVM value (EDR only). */
/* See BlueTooth Testing Documentation. */
/* Single element real vector is returned. */
#define WT_RES_BT_RMS_DEVM                 "EdrEVMAv"

/* Pk Differential EVM value (EDR only). */
/* See BlueTooth Testing Documentation. */
/* Single element real vector is returned. */
#define WT_RES_BT_PK_DEVM                  "EdrEVMpk"

/* Relative power of EDR section to FM section of packet, in dB. */
#define WT_RES_BT_EDR_REL_PWR               "EdrPowDiffdB"

/* The percentage of symbols with EVM below the threshold. Threshold
for 2 Mbps is 0.3 for 3 Mbps is 0.2 */
#define WT_RES_BT_EDR_PROB_99_EVM_PASS     "EdrprobEVM99pass"

/* NEW: In release 1.2 of the Bluetooth Software:
Max DEVM Average as specified in: BLUETOOTH TEST SPECIFICATION
Ver. 1.2/2.0/2.0 + EDR [vol 2] version 2.0.E.2. stBT_DEVM vector returned*/
#define WT_RES_BT_MAX_DEVM_AVG             "EdrEVMvsTime"

/* Omega_i value (EDR only). */
/* Single element real vector is returned. */
#define WT_RES_BT_EDR_OMEAG_I                   "Omega_i"

/* Omega_o value (EDR only). */
/* Single element real vector is returned. */
#define WT_RES_BT_EDR_OMEAG_O                   "Omega_o"

/* Omega_i0 value (EDR only). */
/* Single element real vector is returned. */
#define WT_RES_BT_EDR_OMEAG_IO                  "Omega_io"

/* Bandwidth-20dB Passed Or Failed. Int Value */
/* A value of 1 indicates BW20dB passed. */
/* A value of 0 indicates BW20dB doesn't passed, and thus empty. */
/* Single element vector is returned. See BlueTooth Testing Documentation. */
#define WT_RES_BT_BANDWIDTH_20DB_Passed     "BW20dB_Passed"

/* 20 dB bandwidth value Hz. See BlueTooth Testing Documentation. */
/* stBT_BW20dB vector is returned. */
#define WT_RES_BT_BANDWIDTH_20DB           "bandwidth20dB"

/* Bandwidth-20dB rbw HZ. double value */
#define WT_RES_BT_BANDWIDTH_20DB_RBW    "bandwidth20dBRbw"

/* Bandwidth-20dB obw HZ. double value */
#define WT_RES_BT_BANDWIDTH_20DB_OBW    "bandwidth20dBObw"

//BT BLE FnMax,Hz
#define WT_RES_BT_BLE_FnMax                 "FnMax"

//BT BLE F0FnMax,Hz
#define WT_RES_BT_BLE_F0FnMax               "F0FnMax"

//BT BLE Delta_F1F0,Hz
#define WT_RES_BT_BLE_Delta_F1F0            "Delta_F1F0"

//BT BLE F0Fn5_Max,Hz
#define WT_RES_BT_BLE_F0Fn5_Max             "FnFn5_Max"

//BT BLE Delta_F1_MAX
#define WT_RES_BT_DELTA_F1_MAX                 "deltaF1Max"

//BT BLE Delta_F0F3,Hz
#define WT_RES_BT_BLE_Delta_F0F3            "Delta_F0F3"

//BT BLE Delta_F0Fn3,Hz
#define WT_RES_BT_BLE_Delta_F0FN3            "Delta_F0Fn3"

//BT BLE Freq Drift Detail Valid. Int Value
#define WT_RES_BT_BLE_DRIFT_DETAIL_VALID    "BLE_drift_detail_valid"

//BT BR/BLE Spectrum adjacent Channel Power,dBm
#define WT_RES_BT_SPEC_ACP             "Spectrum_Acp"

//BT BR/BLE Spectrum adjacent Channel Power mask, Complex vector
#define WT_RES_BT_SPEC_ACP_MASK     "Spectrum_Acp_mask"

//BT BR/BLE名称：DetaF2Max Pass Rate，单位：%（保留两位小数）
#define WT_RES_BT_DELTA_F2_PASS_PERCENT     "Delta_F2_pass_percent"

//BT BR/BDR Freq offset header
#define WT_RES_BT_FREQ_OFFSET_HEADER         "freq_offset_header"

//BT BLE Freq offset sync
#define WT_RES_BT_FREQ_OFFSET_SYNC          "freq_offset_sync"
/* Similar to the measurement result for deltaF1Avg as specified in
BLUETOOTH TEST SPECIFICATION Ver. 1.2/2.0/2.0 + EDR [vol 2] version 2.0.E.2.
BT BR/EDR Result measured from Header data. Result in Hz.*/
#define WT_RES_BT_RES_FREQ_DEV              "freq_deviation"

/* BT BR/EDR Peak to Peak Frequency Deviation, in Hz during header*/
#define WT_RES_BT_RES_FREQ_DEV_PK_TO_PK     "freq_deviationpktopk"

/*BT BR/EDR Delta av access*/
#define WT_RES_BT_DELTA_F2_AVG_ACCESS        "Delta_F2_Av_Access"

/*BT BR/EDR Delta max access*/
#define WT_RES_BT_DELTA_F2_MAX_ACCESS       "Delta_F2_Max_Access"

//====================================================================

//Frame start and end place is return
#define WT_RES_FRAME_LOCATION       "Power.Frame.Location"

//Evm Specification db
#define WT_RES_EVM_SPECIFICATION_DB "evm.specification.db"

//Mimo real stream count,according to real vsg stream
#define WT_RES_STREAM_COUNT         "mimo.stream.count"

/*PSDU Scramble sequence result,u8 vetor is return,result eg:0100101,ax的不用这个获取*/
#define WT_RES_PSDU_SCRAMBLE        "psdu_scramble"

/*DUT Mac Info， struct stMacInfo is return,support 11ag 11n, 11ac*/
#define WT_RES_MAC_INFO             "Mac_info"

/*PSDU CRC result ,int value is return,只获取11a, n, ac的，ax的在ofdma info中*/
#define WT_RES_PSDU_CRC             "PSDU_CRC"

/*===========================================================================
 special for 11ax result
 ===========================================================================*/
/*11ax per user Mac Info，vector struct stMacInfo is return*/
#define WT_RES_11AX_USER_MAC_INFO   "Ax11_User_Mac_info"

/*11ax per user PSDU Scramble sequence result,u8 vetor is return,result eg:0100101，只是ax的*/
#define WT_RES_11AX_PSDU_SCRAMBLE   "Ax11_psdu_scramble"

/*11ax mu mimo, ofdma into,vector struct RuOfdmaInfo11ax is return*/
#define WT_RES_11AX_MU_MIMO_OFDMA_INFO      "Ax11_Mu_Mimo.Ofdma_info"

/*11ax mu mimo, all user's const data*/
#define WT_RES_MU_MIMO_ALL_USER_CONST_DATA  "mumimo.all.user.const.data"

/*11ax mu mimo, all user's const ref*/
#define WT_RES_MU_MIMO_ALL_USER_CONST_REF   "mumimo.all.user.const.ref"

/*11ax mu mimo, all user's const pilot*/
#define WT_RES_MU_MIMO_ALL_USER_CONST_PILOT "mumimo.all.user.const.pilot"

/*11ax A-mpdu信息,8080要取组合结果，所以和其他协议分开*/
#define WT_RES_11AX_A_MPDU                       "Ax11_ampdu.info"
/*===========================================================================
 Ofdm result
 ===========================================================================*/
/*ac mu mimo, all user's const data，ac8080也是按普通的取所以和ax分开*/
#define WT_RES_AC_MU_MIMO_ALL_USER_CONST_DATA  "ac_mumimo.all.user.const.data"

/*ac mu mimo, all user's const ref*/
#define WT_RES_AC_MU_MIMO_ALL_USER_CONST_REF   "ac_mumimo.all.user.const.ref"

/*ac mu mimo, all user's const pilot*/
#define WT_RES_AC_MU_MIMO_ALL_USER_CONST_PILOT "ac_mumimo.all.user.const.pilot"

/*11ac mu mimo 返回data info信息*/
#define WT_RES_11AC_MU_MIMO_DATA_INFO       "mumimo.data.info"

/*A-mpdu信息，n，ac*/
#define WT_RES_A_MPDU                       "ampdu.info"

/*EVM 余量 db, double value is return */
#define WT_RES_EVM_MARGIN               "evm_margin"

/* LO 余量 db, double value is return */
#define WT_RES_LEAGKAGE_MARGIN           "Leagkage_margin"

/*频偏余量ppm, double value is return */
#define WT_RES_FREQ_ERR_MARGIN           "freqerr_margin"

/*采样偏余量 ppm, double value is return */
#define WT_RES_CLOCK_ERR_MARGIN           "clockerr_margin"

/*LO参考量dB, double value is return */
#define WT_RES_LEAGKAGE_SPECIFICATION_DB    "LO.specification.db"

/*频偏参考量ppm, double value is return */
#define WT_RES_FREQ_ERR_SPECIFICATION_PPM   "Freqerr.specification.ppm"

/*采样参考量ppm, double value is return */
#define WT_RES_CLOCK_ERR_SPECIFICATION_PPM  "Clockerr.specification.ppm"

/*export PSDU data char vector value is return*/
#define WT_RES_EXPORT_PSDU_BIT              "Psdu_bit"
/*===========================================================================
 zwave result
 ===========================================================================*/
/* zwave eye data. stZWave_eye Vector */
#define WT_RES_ZWAVE_EYE             "Zwave.eye"
#endif
